@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "time-zones" "0.5.2"
+(define-package "time-zones" "20251103.936"
   "Time zone lookups."
   '((emacs "28.1"))
   :url "https://github.com/xenodium/time-zones"
-  :commit "fd94705f04b1e5bc4a9b08ef9092fea839fe92d7"
-  :revdesc "fd94705f04b1")
+  :commit "23c866db6a3aecac5e860cda6010d9afc847e5c6"
+  :revdesc "23c866db6a3a")
